package com.ruoyi.web.controller.learn;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.learn.domain.LearnPaperQuestion;
import com.ruoyi.learn.service.ILearnPaperQuestionService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 试卷题关系Controller
 * 
 * @author ruoyi
 * @date 2025-09-18
 */
@RestController
@RequestMapping("/learn/paper_question")
public class LearnPaperQuestionController extends BaseController
{
    @Autowired
    private ILearnPaperQuestionService learnPaperQuestionService;

    /**
     * 查询试卷题关系列表
     */
    @PreAuthorize("@ss.hasPermi('learn:paper_question:list')")
    @GetMapping("/list")
    public TableDataInfo list(LearnPaperQuestion learnPaperQuestion)
    {
        startPage();
        List<LearnPaperQuestion> list = learnPaperQuestionService.selectLearnPaperQuestionList(learnPaperQuestion);
        return getDataTable(list);
    }

    /**
     * 导出试卷题关系列表
     */
    @PreAuthorize("@ss.hasPermi('learn:paper_question:export')")
    @Log(title = "试卷题关系", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LearnPaperQuestion learnPaperQuestion)
    {
        List<LearnPaperQuestion> list = learnPaperQuestionService.selectLearnPaperQuestionList(learnPaperQuestion);
        ExcelUtil<LearnPaperQuestion> util = new ExcelUtil<LearnPaperQuestion>(LearnPaperQuestion.class);
        util.exportExcel(response, list, "试卷题关系数据");
    }

    /**
     * 获取试卷题关系详细信息
     */
    @PreAuthorize("@ss.hasPermi('learn:paper_question:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(learnPaperQuestionService.selectLearnPaperQuestionById(id));
    }

    /**
     * 新增试卷题关系
     */
    @PreAuthorize("@ss.hasPermi('learn:paper_question:add')")
    @Log(title = "试卷题关系", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LearnPaperQuestion learnPaperQuestion)
    {
        return toAjax(learnPaperQuestionService.insertLearnPaperQuestion(learnPaperQuestion));
    }

    /**
     * 修改试卷题关系
     */
    @PreAuthorize("@ss.hasPermi('learn:paper_question:edit')")
    @Log(title = "试卷题关系", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LearnPaperQuestion learnPaperQuestion)
    {
        return toAjax(learnPaperQuestionService.updateLearnPaperQuestion(learnPaperQuestion));
    }

    /**
     * 删除试卷题关系
     */
    @PreAuthorize("@ss.hasPermi('learn:paper_question:remove')")
    @Log(title = "试卷题关系", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(learnPaperQuestionService.deleteLearnPaperQuestionByIds(ids));
    }
}
